@@ -5,6 +5,7 @@ from pathlib import Path
 from jinja2 import Template
 
 from ..core.errors import Err, Exc, Ok
+from ..database import Database
 
 
 class TaskStatus(Enum):
@@ -79,18 +80,15 @@ class Task:
     # Status methods
 
     def ready(self):
-        """(Deprecated: use `success` instead) Returned on successful execution.
-        """
+        """(Deprecated: use `success` instead) Returned on successful execution."""
         return Ok()
 
     def success(self):
-        """Returned on successful execution.
-        """
+        """Returned on successful execution."""
         return Ok()
 
     def fail(self, msg=None):
-        """Returned on failure in any stage.
-        """
+        """Returned on failure in any stage."""
         if msg is None:
             msg = 'Unknown error. Use `self.fail("Error message")` in python tasks for more details.'
         return Err("tasks", "task_fail", message=msg)
@@ -101,6 +99,10 @@ class Task:
         """Sets the run steps for the task, allowing the CLI to indicate task execution progress. """
         self.tracker.set_run_steps(steps)
 
+    def add_run_steps(self, steps):
+        """Adds new steps to the list of run steps for the task, allowing the CLI to indicate task execution progress. """
+        self.tracker.add_run_steps(steps)
+
     def start_step(self, step):
         """Specifies the start of a task step"""
         self.tracker.start_step(step)
@@ -219,6 +221,28 @@ class Task:
 
         return Ok()
 
+    # Execution utilities
+
+    def use_db_object(
+        self, object_name, schema=None, tmp_schema=None, db=None, request_tmp=True
+    ):
+        if db is None:
+            target_db = self.default_db
+        elif isinstance(db, str):
+            target_db = self.connections[db]
+        elif isinstance(db, Database):
+            target_db = db
+        else:
+            return Err("use_db_object", "wrong_db_type")
+
+        target_db._request_object(
+            object_name,
+            schema=schema,
+            tmp_schema=tmp_schema,
+            task_name=self.name,
+            request_tmp=request_tmp,
+        )
+
 
 class PythonTask(Task):
     def setup(self):
